==> apache-pulsar-3.0.15-src.tar.gz: apache-pulsar-3.0.15-src/pulsar-client-admin-api/src/main/java/org/apache/pulsar/common/policies/data/TransactionBufferStats.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.policies.data;

import java.util.Map;

public class TransactionBufferStats {

    /** The state of this transaction buffer. */
    public String state;

    /** The max read position of this transaction buffer. */
    public String maxReadPosition;

    /** The last snapshot timestamps of this transaction buffer. */
    public long lastSnapshotTimestamps;

    /**
     * (Optional) The lowWaterMark details of the transaction buffer.
     */
    public Map<Long, Long> lowWaterMarks;
    /**
     * The total number of ongoing transactions in this transaction buffer.
     */
    public long ongoingTxnSize;

    //Start timestamp of  transaction buffer recovery. 0L means no startup.
    public long recoverStartTime;
    //End timestamp of transaction buffer recovery. 0L means no startup.
    public long recoverEndTime;
}

==> apache-pulsar-4.1.1-src.tar.gz: apache-pulsar-4.1.1-src/pulsar-client-admin-api/src/main/java/org/apache/pulsar/common/policies/data/TransactionBufferStats.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.policies.data;

import java.util.Map;

public class TransactionBufferStats {

    /** The state of this transaction buffer. */
    public String state;

    /** The max read position of this transaction buffer. */
    public String maxReadPosition;

    /** The last snapshot timestamps of this transaction buffer. */
    public long lastSnapshotTimestamps;

    /**
     * (Optional) The lowWaterMark details of the transaction buffer.
     */
    public Map<Long, Long> lowWaterMarks;
    /**
     * The total number of ongoing transactions in this transaction buffer.
     */
    public long ongoingTxnSize;

    //Start timestamp of  transaction buffer recovery. 0L means no startup.
    public long recoverStartTime;
    //End timestamp of transaction buffer recovery. 0L means no startup.
    public long recoverEndTime;

    // The total number of aborted transactions.
    public long totalAbortedTransactions;

    // The type of snapshot being used: either "Single" or "Segment"
    public String snapshotType;

    // If snapshotType is "Segment", this field will provide additional segment-related statistics
    public SegmentsStats segmentsStats;
}
